@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2016-2020 Fabian Hofmann (FIAS), Jonas Hoersch (KIT, IAI) and
 # Fabian Gotzens (FZJ, IEK-STE)
 
@@ -20,9 +19,6 @@ Collection of power plant data bases and statistical data
 
 import logging
 import os
-import re
-import xml.etree.ElementTree as ET
-from distutils.log import debug
 from zipfile import ZipFile
 
 import entsoe
@@ -39,13 +35,12 @@ from .cleaning import (
     gather_specifications,
     gather_technology_info,
 )
-from .core import _data_in, _package_data, get_config
+from .core import _package_data, get_config
 from .heuristics import scale_to_net_capacities
 from .utils import (
     config_filter,
     convert_to_short_name,
     correct_manually,
-    fill_geoposition,
     get_raw_file,
     set_column_name,
 )
@@ -109,6 +104,7 @@ def BEYONDCOAL(raw=False, update=False, config=None):
         )
         .pipe(scale_to_net_capacities)
         .pipe(clean_name)
+        .pipe(convert_to_short_name)
         .pipe(set_column_name, "BEYONDCOAL")
         .pipe(config_filter, config)
     )
@@ -267,7 +263,7 @@ def GEO(raw=False, update=False, config=None):
 
     def to_year(ds):
         years = pd.to_numeric(ds.dropna().astype(str).str[:4], errors="coerce")
-        year = years[lambda x: x > 1900]
+        year = years[lambda x: x > 1900]  # noqa
         return years.reindex_like(ds)
 
     fn = get_raw_file("GEO_units", update=update, config=config)
@@ -298,7 +294,7 @@ def GEO(raw=False, update=False, config=None):
     ppl = clean_name(ppl)
 
     res = units.join(ppl.set_index("projectID"), "projectID", rsuffix="_ppl")
-    res.DateIn.fillna(res.DateIn_ppl, inplace=True)
+    res["DateIn"] = res.DateIn.fillna(res.DateIn_ppl)
     not_included_ppl = ppl.query("projectID not in @res.projectID")
     res = pd.concat([res, not_included_ppl]).pipe(set_column_name, "GEO")
     res = scale_to_net_capacities(res)
@@ -365,9 +361,9 @@ def CARMA(raw=False, update=False, config=None):
                     "GEO": "Geothermal",
                     "WSTH": "Waste",
                     "SUN": "Solar",
-                    "BLIQ": "Bioenergy",
-                    "BGAS": "Bioenergy",
-                    "BSOL": "Bioenergy",
+                    "BLIQ": "Solid Biomass",
+                    "BGAS": "Biogas",
+                    "BSOL": "Solid Biomass",
                     "OTH": "Other",
                 }
             )
@@ -403,10 +399,7 @@ def JRC(raw=False, update=False, config=None):
 
     fn = get_raw_file("JRC", update, config)
 
-    with ZipFile(fn, "r") as file:
-        directory = file.namelist()[0]
-        key = directory + "data/jrc-hydro-power-plant-database.csv"
-        df = pd.read_csv(file.open(key))
+    df = pd.read_csv(fn)
 
     if raw:
         return df
@@ -531,7 +524,7 @@ def Capacity_stats(
     else:
         source = "Capacity statistics"
 
-    fueltypes = config["target_fueltypes"]
+    fueltypes = config["target_fueltypes"]  # noqa
     df = (
         df.query("year == @year")
         .rename(columns={"technology": "Fueltype"})
@@ -583,8 +576,8 @@ def GPD(raw=False, update=False, config=None, filter_other_dbs=True):
 
     other_dbs = []
     if filter_other_dbs:
-        other_dbs = ["GEODB", "Open Power System Data", "ENTSOE"]
-    countries = config["target_countries"]
+        other_dbs = ["GEODB", "Open Power System Data", "ENTSOE"]  # noqa
+    countries = config["target_countries"]  # noqa
     return (
         df.rename(columns=lambda x: x.title())
         .drop(columns="Country")
@@ -637,6 +630,7 @@ def WIKIPEDIA(raw=False, update=False, config=None):
     df = (
         df.rename(columns=RENAME_COLUMNS)
         .pipe(clean_name)
+        .pipe(convert_to_short_name)
         .assign(
             Fueltype="Nuclear",
             Set="PP",
@@ -958,11 +952,11 @@ def WEPP(raw=False, config=None):
     )
     # Replace fueltypes
     d = {
-        "AGAS": "Bioenergy",  # Syngas from gasified agricultural waste
+        "AGAS": "Solid Biomass",  # Syngas from gasified agricultural waste
         "BFG": "Other",  # blast furnance gas -> "Hochofengas"
-        "BGAS": "Bioenergy",
-        "BIOMASS": "Bioenergy",
-        "BL": "Bioenergy",
+        "BGAS": "Biogas",
+        "BIOMASS": "Solid Biomass",
+        "BL": "Solid Biomass",
         "CGAS": "Hard Coal",
         "COAL": "Hard Coal",
         "COG": "Other",  # coke oven gas -> deutsch: "Hochofengas"
@@ -979,13 +973,13 @@ def WEPP(raw=False, config=None):
         "JET": "Oil",  # Jet fuels
         "KERO": "Oil",  # Kerosene
         "LGAS": "Other",  # landfill gas -> deutsch: "Deponiegas"
-        "LIGNIN": "Bioenergy",
+        "LIGNIN": "Solid Biomass",
         "LIQ": "Other",  # (black) liqour -> deutsch: "Schwarzlauge",
         #    die bei Papierherstellung anfaellt
         "LNG": "Natural Gas",  # Liquified natural gas
         "LPG": "Natural Gas",  # Liquified petroleum gas (u. butane/propane)
-        "MBM": "Bioenergy",  # Meat and bonemeal
-        "MEDWST": "Bioenergy",  # Medical waste
+        "MBM": "Solid Biomass",  # Meat and bonemeal
+        "MEDWST": "Solid Biomass",  # Medical waste
         "MGAS": "Other",  # mine gas -> deutsch: "Grubengas"
         "NAP": "Oil",  # naphta
         "OGAS": "Oil",  # Gasified crude oil/refinery bottoms/bitumen
@@ -1002,8 +996,8 @@ def WEPP(raw=False, config=None):
         "UNK": "Other",
         "UR": "Nuclear",
         "WAT": "Hydro",
-        "WOOD": "Bioenergy",
-        "WOODGAS": "Bioenergy",
+        "WOOD": "Solid Biomass",
+        "WOODGAS": "Solid Biomass",
         "WSTGAS": "Other",  # waste gas -> deutsch: "Industrieabgas"
         "WSTWSL": "Waste",  # Wastewater sludge
         "WSTH": "Waste",
@@ -1014,9 +1008,9 @@ def WEPP(raw=False, config=None):
     wepp.Turbtype.fillna("", inplace=True)
     # Correct technology infos:
     wepp.loc[wepp.Technology.str.contains("LIG", case=False), "Fueltype"] = "Lignite"
-    wepp.loc[
-        wepp.Turbtype.str.contains("KAPLAN|BULB", case=False), "Technology"
-    ] = "Run-Of-River"
+    wepp.loc[wepp.Turbtype.str.contains("KAPLAN|BULB", case=False), "Technology"] = (
+        "Run-Of-River"
+    )
     wepp.Technology = wepp.Technology.replace(
         {
             "CONV/PS": "Pumped Storage",
@@ -1136,8 +1130,7 @@ def UBA(
 ):
     """
     Importer for the UBA Database. Please download the data from
-    `<https://www.umweltbundesamt.de/dokument/datenbank-kraftwerke-in
-    -deutschland>`_.
+    `<https://www.umweltbundesamt.de/dokument/datenbank-kraftwerke-in-deutschland>`_.
 
     Parameters
     ----------
@@ -1207,7 +1200,7 @@ def UBA(
         .str[0]
         .astype(float),
         Country="Germany",
-        projectID=["UBA{:03d}".format(i + header + 2) for i in uba.index],
+        projectID=[f"UBA{i + header + 2:03d}" for i in uba.index],
         Technology=uba.Technology.replace(RENAME_TECHNOLOGY),
     )
     uba.loc[uba.CHP.notnull(), "Set"] = "CHP"
@@ -1221,7 +1214,7 @@ def UBA(
     uba.loc[uba.Fueltype.str.contains("HEL"), "Fueltype"] = "Oil"
     uba.Fueltype = uba.Fueltype.replace(
         {
-            "Biomasse": "Bioenergy",
+            "Biomasse": "Solid Biomass",
             "Gichtgas": "Other",
             "HS": "Oil",
             "Konvertergas": "Other",
@@ -1232,7 +1225,7 @@ def UBA(
             "\xd6lr\xfcckstand": "Oil",
         }
     )
-    uba.Name.replace([r"(?i)oe", r"(?i)ue"], ["ö", "ü"], regex=True, inplace=True)
+    uba["Name"] = uba.Name.replace([r"(?i)oe", r"(?i)ue"], ["ö", "ü"], regex=True)
     if prune_wind:
         uba = uba.loc[lambda x: x.Fueltype != "Wind"]
     if prune_solar:
@@ -1367,9 +1360,9 @@ def BNETZA(
         "Pumpspeicher": "Pumped Storage",
     }
     for fuel in techmap:
-        bnetza.loc[
-            bnetza.Fueltype.str.contains(fuel, case=False), "Technology"
-        ] = techmap[fuel]
+        bnetza.loc[bnetza.Fueltype.str.contains(fuel, case=False), "Technology"] = (
+            techmap[fuel]
+        )
     # Fueltypes
     bnetza.Fueltype.replace(
         {
@@ -1381,7 +1374,7 @@ def BNETZA(
             ".*(?i)energietr.*ger.*\n.*": "Other",
             "Kern.*": "Nuclear",
             "Mineral.l.*": "Oil",
-            "Biom.*": "Bioenergy",
+            "Biom.*": "Solid Biomass",
             ".*(?i)(e|r|n)gas": "Other",
             "Geoth.*": "Geothermal",
             "Abfall": "Waste",
@@ -1521,39 +1514,48 @@ def IRENASTAT(raw=False, update=False, config=None):
 
     fn = get_raw_file("IRENA", update=update, config=config)
 
-    df = pd.read_csv(fn, comment="#")
+    df = pd.read_csv(fn, comment="#", quotechar='"')
 
     if raw:
         return df
 
     RENAME_COLUMNS = {
-        "Installed electricity capacity by country/area (MW)": "Capacity",
+        "Electricity statistics": "Capacity",
         "Country/area": "Country",
         "Grid connection": "Grid",
     }
     df.rename(columns=RENAME_COLUMNS, inplace=True)
 
+    df.drop(columns="Data Type", inplace=True)
+
+    # Rename all entries "Congo (the)" to "Congo" under the column
+    # "Country"; the former confuses country_converter.
+    df["Country"] = df["Country"].replace("Congo (the)", "Congo")
+
     # Consistent country names for dataset
     df = convert_to_short_name(df)
 
     df.dropna(subset="Capacity", inplace=True)
 
+    # Remove all rows where Technology is just a Total
+    df = df[
+        ~df.Technology.str.contains("Total Renewable|Total Non-Renewable", na=False)
+    ]
+
     fueltype_dict = {
-        "On-grid Solar photovoltaic": "Solar",
-        "Off-grid Solar photovoltaic": "Solar",
-        "Concentrated solar power": "Solar",
+        "Solar photovoltaic": "Solar",
+        "Solar thermal energy": "Solar",
         "Onshore wind energy": "Wind",
         "Offshore wind energy": "Wind",
         "Renewable hydropower": "Hydro",
         "Mixed Hydro Plants": "Hydro",
         "Pumped storage": "Hydro",
-        "Solid biofuels": "Bioenergy",
+        "Solid biofuels": "Solid Biomass",
         "Renewable municipal waste": "Waste",
-        "Liquid biofuels": "Bioenergy",
-        "Biogas": "Bioenergy",
+        "Liquid biofuels": "Solid Biomass",
+        "Biogas": "Biogas",
         "Geothermal energy": "Geothermal",
         "Marine energy": "Marine",
-        "Fossil fuels": "Other",
         "Coal and peat": "Hard Coal",
         "Oil": "Oil",
         "Natural gas": "Natural Gas",
@@ -1563,9 +1565,8 @@ def IRENASTAT(raw=False, update=False, config=None):
     }
 
     technology_dict = {
-        "On-grid Solar photovoltaic": "PV",
-        "Off-grid Solar photovoltaic": "PV",
-        "Concentrated solar power": "CSP",
+        "Solar photovoltaic": "PV",
+        "Solar thermal energy": "CSP",
         "Onshore wind energy": "Onshore",
         "Offshore wind energy": "Offshore",
         "Pumped storage": "Pumped Storage",
@@ -1574,14 +1575,407 @@ def IRENASTAT(raw=False, update=False, config=None):
     }
 
     df["Fueltype"] = df.Technology.map(fueltype_dict)
-    df.Technology.replace(technology_dict, inplace=True)
+    df["Technology"] = df.Technology.replace(technology_dict)
 
-    l = list(set(df.columns).difference(set(["Capacity"])))
-    df = df.groupby(l, as_index=False, dropna=True).sum()
+    non_capacity_columns = list(set(df.columns).difference(set(["Capacity"])))
+    df = df.groupby(non_capacity_columns, as_index=False, dropna=True).sum()
 
     return df
 
 
+def GBPT(raw=False, update=False, config=None):
+    """
+    Importer for the global bioenergy powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+    config = get_config() if config is None else config
+    fn = get_raw_file("GBPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Data")
+
+    if raw:
+        return df
+
+    RENAME_COLUMNS = {
+        "Project name": "Name",
+        "Capacity (MW)": "Capacity",
+        "Fuel 1": "Fueltype",
+        "Operating status": "Status",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Unit start year": "DateIn",
+        "Retired year": "DateOut",
+        "GEM phase ID": "projectID",
+    }
+    fueltype_dict = {
+        "bioenergy - agricultural waste (solids)": "Solid Biomass",
+        "bioenergy - refuse (municipal and industrial wastes)": "Solid Biomass",
+        "bioenergy - refuse (syngas)": "Solid Biomass",
+        "bioenergy - agricultural waste (biogas)": "Biogas",
+        "bioenergy - wood & other biomass (solids)": "Solid Biomass",
+        "bioenergy - ethanol": "Solid Biomass",
+        "bioenergy - paper mill wastes": "Solid Biomass",
+        "bioenergy - biodiesel": "Solid Biomass",
+        "bioenergy - unknown": "Solid Biomass",
+        "bioenergy - wastewater and sewage sludge (solids or biogas)": "Solid Biomass",
+        "bioenergy - refuse (landfill gas)": "Biogas",
+        "bioenergy - agricultural waste (unknown)": "Solid Biomass",
+        "bioenergy - agricultural waste (syngas)": "Solid Biomass",
+        "bioenergy - wood & other biomass (biocoal)": "Solid Biomass",
+    }
+
+    status_list = config["GBPT"].get("status", ["operating"])  # noqa: F841
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GBPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .pipe(lambda x: x.replace({"Fueltype": fueltype_dict}))
+        .assign(Technology="Steam Turbine")
+        .assign(Set="PP")
+        .pipe(config_filter, config)
+    )
+    return df_final
+
+
+def GNPT(raw=False, update=False, config=None):
+    """
+    Importer for the global nuclear energy powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+    config = get_config() if config is None else config
+    fn = get_raw_file("GNPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Data")
+
+    if raw:
+        return df
+
+    RENAME_COLUMNS = {
+        "Project Name": "Name",
+        "Capacity (MW)": "Capacity",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Start Year": "DateIn",
+        "Retirement Year": "DateOut",
+        "Country/Area": "Country",
+        "GEM unit ID": "projectID",
+    }
+
+    status_list = config["GNPT"].get("status", ["operating"])  # noqa: F841
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GNPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .assign(Fueltype="Nuclear")
+        .assign(Technology="Steam Turbine")
+        .assign(Set="PP")
+        .pipe(config_filter, config)
+    )
+    return df_final
+
+
+def GCPT(raw=False, update=False, config=None):
+    """
+    Importer for the global coal powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+
+    config = get_config() if config is None else config
+    fn = get_raw_file("GCPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Units")
+
+    if raw:
+        return df
+
+    RENAME_COLUMNS = {
+        "Plant name": "Name",
+        "Combustion technology": "Technology",
+        "Coal type": "Fueltype",
+        "Capacity (MW)": "Capacity",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Start year": "DateIn",
+        "Retired year": "DateOut",
+        "Country/Area": "Country",
+        "GEM unit/phase ID": "projectID",
+    }
+    fueltype_dict = {
+        "bituminous": "Hard Coal",
+        "lignite": "Lignite",
+        "unknown": "Hard Coal",
+        "subbituminous": "Hard Coal",
+        "waste coal": "Hard Coal",
+        "anthracite": "Hard Coal",
+        "lignite with CCS": "Lignite",
+        "bituminous with CCS": "Hard Coal",
+        "subbituminous with CCS": "Hard Coal",
+        "unknown with CCS": "Hard Coal",
+    }
+
+    planned_retirement = df["Planned retirement"].apply(pd.to_numeric, errors="coerce")
+
+    status_list = config["GCPT"].get("status", ["operating"])  # noqa: F841
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GCPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .assign(DateOut=lambda x: x["DateOut"].combine_first(planned_retirement))
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .pipe(lambda x: x.replace({"Fueltype": fueltype_dict}))
+        .pipe(lambda x: x.assign(Technology="Steam Turbine"))
+        .pipe(lambda x: x.assign(Set="PP"))
+        .pipe(config_filter, config)
+    )
+
+    return df_final
+
+
+def GGTPT(raw=False, update=False, config=None):
+    """
+    Importer for the global geothermal powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+    config = get_config() if config is None else config
+    fn = get_raw_file("GGTPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Data")
+
+    if raw:
+        return df
+
+    RENAME_COLUMNS = {
+        "Project Name": "Name",
+        "Capacity (MW)": "Capacity",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Start year": "DateIn",
+        "Retired year": "DateOut",
+        "Country/Area": "Country",
+        "GEM unit ID": "projectID",
+    }
+
+    status_list = config["GGTPT"].get("status", ["operating"])  # noqa: F841
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GGTPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .assign(Fueltype="Geothermal")
+        .assign(Technology="Steam Turbine")
+        .assign(Set="PP")
+        .pipe(config_filter, config)
+    )
+    return df_final
+
+
+def GWPT(raw=False, update=False, config=None):
+    """
+    Importer for the global wind powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+    config = get_config() if config is None else config
+    fn = get_raw_file("GWPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Data")
+
+    RENAME_COLUMNS = {
+        "Project Name": "Name",
+        "Capacity (MW)": "Capacity",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Start year": "DateIn",
+        "Retired year": "DateOut",
+        "GEM phase ID": "projectID",
+        "Installation Type": "Technology",
+        "Country/Area": "Country",
+    }
+
+    technology_dict = {
+        "Onshore": "Onshore",
+        "Offshore hard mount": "Offshore",
+        "Offshore floating": "Offshore",
+        "Offshore mount unknown": "Offshore",
+    }
+
+    status_list = config["GWPT"].get("status", ["operating"])  # noqa: F841
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GWPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .pipe(lambda x: x.replace({"Technology": technology_dict}))
+        .assign(Fueltype="Wind")
+        .assign(Set="PP")
+        .pipe(config_filter, config)
+    )
+    return df_final
+
+
+def GSPT(raw=False, update=False, config=None):
+    """
+    Importer for the global solar powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+
+    config = get_config() if config is None else config
+    fn = get_raw_file("GSPT", update=update, config=config)
+    large = pd.read_excel(fn, sheet_name="20 MW+")
+    small = pd.read_excel(fn, sheet_name="1-20 MW")
+    df = pd.concat([large, small], ignore_index=True)
+
+    if raw:
+        return df
+
+    RENAME_COLUMNS = {
+        "Project Name": "Name",
+        "Capacity (MW)": "Capacity",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Start year": "DateIn",
+        "Retired year": "DateOut",
+        "Technology Type": "Technology",
+        "GEM phase ID": "projectID",
+        "Country/Area": "Country",
+    }
+
+    technology_dict = {
+        "PV": "PV",
+        "Solar Thermal": "CSP",
+        "Assumed PV": "PV",
+    }
+
+    status_list = config["GSPT"].get("status", ["operating"])  # noqa: F841
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GSPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .pipe(lambda x: x.replace({"Technology": technology_dict}))
+        .assign(Fueltype="Solar")
+        .assign(Set="PP")
+        .pipe(config_filter, config)
+    )
+    return df_final
+
+
 def GGPT(raw=False, update=False, config=None):
     """
     Importer for the global gas powerplant tracker from global energy monitor.
@@ -1599,7 +1993,7 @@ def GGPT(raw=False, update=False, config=None):
     """
     config = get_config() if config is None else config
     fn = get_raw_file("GGPT", update=update, config=config)
-    df = pd.read_excel(fn, sheet_name="Gas plants - data")
+    df = pd.read_excel(fn, sheet_name="Gas & Oil Units")
 
     if raw:
         return df
@@ -1607,22 +2001,24 @@ def GGPT(raw=False, update=False, config=None):
     RENAME_COLUMNS = {
         "Plant name": "Name",
         "Fuel": "Fueltype",
-        "Capacity elec. (MW)": "Capacity",
+        "Capacity (MW)": "Capacity",
         "Latitude": "lat",
         "Longitude": "lon",
         "Start year": "DateIn",
         "Retired year": "DateOut",
         "CHP": "Set",
-        "GEM unit ID": "projectID",
+        "GEM location ID": "projectID",
     }
 
     technology_dict = {
         "GT": "Steam Turbine",
+        "IC": "Steam Turbine",
         "CC": "CCGT",
         "GT/IC": "Steam Turbine",
         "ICCC": "CCGT",
         "ISCC": "CCGT",
         "ST": "Steam Turbine",
+        "AFC": "CCGT",
     }
 
     set_dict = {
@@ -1631,25 +2027,120 @@ def GGPT(raw=False, update=False, config=None):
         "not found": "PP",
     }
 
-    df = (
-        df.rename(columns=RENAME_COLUMNS)
-        .pipe(clean_name)
+    status_list = config["GGPT"].get("status", ["operating"])  # noqa: F841
+    gas_fuels = ["NG", "LNG", "BU", "LFG", "BG", "BFG", "COG", "CM", "H", "OG"]
+
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
         .pipe(set_column_name, "GGPT")
         .pipe(convert_to_short_name)
         .dropna(subset="Capacity")
-        .assign(Fueltype="Natural Gas")[
-            lambda df: df.Status.isin(["operating", "mothballed", "construction"])
-        ]
+        .pipe(lambda x: x.query("Capacity != 'not found'"))
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+            Capacity=lambda df: pd.to_numeric(df.Capacity, "coerce"),
+            Fueltype=df["Fueltype"].apply(
+                lambda s: (
+                    "Natural Gas"
+                    if any(sub in gas_fuels for sub in s.split("/"))
+                    else "Oil"
+                )
+            ),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .pipe(lambda x: x.replace({"Technology": technology_dict}))
+        .pipe(lambda x: x.replace({"Set": set_dict}).fillna({"Set": "PP"}))
+        .assign(Fueltype="Natural Gas")
+        .pipe(config_filter, config)
     )
-    df["DateIn"] = pd.to_numeric(df.DateIn, errors="coerce")
-    df["lat"] = pd.to_numeric(df.lat, errors="coerce")
-    df["lon"] = pd.to_numeric(df.lon, errors="coerce")
-    df.Technology.replace(technology_dict, inplace=True)
-    df.Set.replace(set_dict, inplace=True)
-    df = df[df.columns.intersection(config.get("target_columns"))]
-    df = df.pipe(config_filter, config)
+    return df_final
 
-    return df
+
+def GHPT(raw=False, update=False, config=None):
+    """
+    Importer for the global gas powerplant tracker from global energy monitor.
+
+    Parameters
+    ----------
+    raw : boolean, default False
+        Whether to return the original dataset
+    update: bool, default False
+        Whether to update the data from the url.
+    config : dict, default None
+        Add custom specific configuration,
+        e.g. powerplantmatching.config.get_config(target_countries='Italy'),
+        defaults to powerplantmatching.config.get_config()
+    """
+    config = get_config() if config is None else config
+    fn = get_raw_file("GHPT", update=update, config=config)
+    df = pd.read_excel(fn, sheet_name="Data")
+
+    if raw:
+        return df
+
+    RENAME_COLUMNS = {
+        "Project Name": "Name",
+        "Capacity (MW)": "Capacity",
+        "Latitude": "lat",
+        "Longitude": "lon",
+        "Start Year": "DateIn",
+        "Retired Year": "DateOut",
+        "GEM unit ID": "projectID",
+        "Country 1": "Country",
+        "Technology Type": "Technology",
+    }
+    technology_dict = {
+        "conventional storage": "Reservoir",
+        "pumped storage": "Pumped Storage",
+        "run-of-river": "Run-Of-River",
+        "conventional and pumped storage": "Pumped Storage",
+        "conventional and run-of-river": "Run-Of-River",
+    }
+    status_list = config["GHPT"].get("status", ["operating"])  # noqa: F841
+    df = df.rename(columns=RENAME_COLUMNS)
+    df_final = (
+        df.pipe(clean_name)
+        .pipe(set_column_name, "GHPT")
+        .pipe(convert_to_short_name)
+        .dropna(subset="Capacity")
+        .assign(
+            DateIn=df["DateIn"].apply(pd.to_numeric, errors="coerce"),
+            DateOut=df["DateOut"].apply(pd.to_numeric, errors="coerce"),
+            lat=df["lat"].apply(pd.to_numeric, errors="coerce"),
+            lon=df["lon"].apply(pd.to_numeric, errors="coerce"),
+        )
+        .query("Status in @status_list")
+        .pipe(lambda x: x[df.columns.intersection(config.get("target_columns"))])
+        .pipe(lambda x: x.replace({"Technology": technology_dict}))
+        .assign(Fueltype="Hydro")
+        .assign(Set="PP")
+        .pipe(config_filter, config)
+    )
+    return df_final
+
+
+def GEM(raw=False, update=False, config=None):
+    """
+    Get the combined dataset of all GEM (https://globalenergymonitor.org/) datasets.
+
+    Parameters
+    ----------
+    raw : bool, optional
+        Whether to return the raw dataset, by default False
+    update : bool, optional
+        Whether to update the raw dataset, by default False
+    config : _type_, optional
+        Custom configuration, by default None
+
+    """
+    GEMS_FUNTIONS = [GBPT, GGPT, GCPT, GGTPT, GNPT, GSPT, GWPT, GHPT]
+    data = [f(raw=raw, update=update, config=config) for f in GEMS_FUNTIONS]
+    return pd.concat(data, ignore_index=True)
 
 
 # deprecated alias for GGPT
